==> dde-daemon_3.2.13.3.orig.tar.xz: dde-daemon-3.2.13.3/misc/ts/com.deepin.daemon.accounts.policy/policy_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>Authenticatie vereist om uw eigen gebruikersgegevens te kunnen veranderen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>Bewerk uw eigen gebruikersgegevens</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>Authenticatie vereist om gebruikersgegevens te kunnen veranderen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>Beheer gebruikersaccounts</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>Authenticatie is vereist om automatisch inloggen in te schakelen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>Automatisch aanmelden inschakelen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>Authenticatie is vereist om automatisch inloggen uit te schakelen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>Automatisch aanmelden uitschakelen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>Authenticatie is vereist om inloggen zonder wachtwoord in te schakelen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation>Inloggen zonder wachtwoord inschakelen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>Authenticatie is vereist om inloggen zonder wachtwoord uit te schakelen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>Inloggen zonder wachtwoord uitschakelen</translation>
		</message>
	</context>
</TS>

==> dde-daemon_5.12.52.orig.tar.xz: dde-daemon-5.12.52/misc/ts/com.deepin.daemon.accounts.policy/policy_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>Authenticatie vereist om je eigen gebruikersgegevens aan te passen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>Eigen gebruikersgegevens aanpassen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>Authenticatie vereist om gebruikersgegevens aan te passen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>Gebruikersaccounts beheren</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>Authenticatie vereist om automatisch aanmelden in te schakelen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>Automatisch aanmelden inschakelen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>Authenticatie vereist om automatisch aanmelden uit te schakelen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>Automatisch aanmelden uitschakelen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>Authenticatie vereist om aanmelden zonder wachtwoord in te schakelen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation>Aanmelden zonder wachtwoord inschakelen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>Authenticatie vereist om aanmelden zonder wachtwoord uit te schakelen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>Aanmelden zonder wachtwoord uitschakelen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.set-keyboard-layout!message" line="0"/>
			<source>Authentication is required to set keyboard layout</source>
			<translation>Authenticatie vereist om de toetsenbordindeling te wijzigen</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.set-keyboard-layout!description" line="0"/>
			<source>Set keyboard layout</source>
			<translation>Toetsenbordindeling instellen</translation>
		</message>
	</context>
</TS>
